==> glue-1.93.0-sources.jar: software/amazon/awscdk/services/glue/ConnectionType.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) The type of the glue connection.
 * <p>
 * If you need to use a connection type that doesn't exist as a static member, you
 * can instantiate a <code>ConnectionType</code> object, e.g: <code>new ConnectionType('NEW_TYPE')</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.483Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.ConnectionType")
public class ConnectionType extends software.amazon.jsii.JsiiObject {

    protected ConnectionType(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ConnectionType(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        JDBC = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ConnectionType.class, "JDBC", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ConnectionType.class));
        KAFKA = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ConnectionType.class, "KAFKA", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ConnectionType.class));
        MONGODB = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ConnectionType.class, "MONGODB", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ConnectionType.class));
        NETWORK = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ConnectionType.class, "NETWORK", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ConnectionType.class));
    }

    /**
     * @param name This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public ConnectionType(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) The connection type name as expected by Connection resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String toString() {
        return software.amazon.jsii.Kernel.call(this, "toString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Designates a connection to a database through Java Database Connectivity (JDBC).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ConnectionType JDBC;

    /**
     * (experimental) Designates a connection to an Apache Kafka streaming platform.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ConnectionType KAFKA;

    /**
     * (experimental) Designates a connection to a MongoDB document database.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ConnectionType MONGODB;

    /**
     * (experimental) Designates a network connection to a data source within an Amazon Virtual Private Cloud environment (Amazon VPC).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ConnectionType NETWORK;

    /**
     * (experimental) The name of this ConnectionType, as expected by Connection resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getName() {
        return software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> glue-1.182.0-sources.jar: software/amazon/awscdk/services/glue/ConnectionType.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) The type of the glue connection.
 * <p>
 * If you need to use a connection type that doesn't exist as a static member, you
 * can instantiate a <code>ConnectionType</code> object, e.g: <code>new ConnectionType('NEW_TYPE')</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * SecurityGroup securityGroup;
 * Subnet subnet;
 * Connection.Builder.create(this, "MyConnection")
 *         .type(ConnectionType.NETWORK)
 *         // The security groups granting AWS Glue inbound access to the data source within the VPC
 *         .securityGroups(List.of(securityGroup))
 *         // The VPC subnet which contains the data source
 *         .subnet(subnet)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:43.445Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.ConnectionType")
public class ConnectionType extends software.amazon.jsii.JsiiObject {

    protected ConnectionType(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ConnectionType(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        JDBC = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ConnectionType.class, "JDBC", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ConnectionType.class));
        KAFKA = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ConnectionType.class, "KAFKA", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ConnectionType.class));
        MONGODB = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ConnectionType.class, "MONGODB", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ConnectionType.class));
        NETWORK = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ConnectionType.class, "NETWORK", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ConnectionType.class));
    }

    /**
     * @param name This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public ConnectionType(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) The connection type name as expected by Connection resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String toString() {
        return software.amazon.jsii.Kernel.call(this, "toString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Designates a connection to a database through Java Database Connectivity (JDBC).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ConnectionType JDBC;

    /**
     * (experimental) Designates a connection to an Apache Kafka streaming platform.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ConnectionType KAFKA;

    /**
     * (experimental) Designates a connection to a MongoDB document database.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ConnectionType MONGODB;

    /**
     * (experimental) Designates a network connection to a data source within an Amazon Virtual Private Cloud environment (Amazon VPC).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ConnectionType NETWORK;

    /**
     * (experimental) The name of this ConnectionType, as expected by Connection resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getName() {
        return software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
